#include <QQuickCanvas>
#include <QImage>
#include <QSGTexture>
#include <QSGSimpleTextureNode>
#include <QDebug>

#include "imageitem.h"

struct ImageItemData
{
    ImageItemData()
        : texture(0) {};

    ~ImageItemData() {
        delete texture;
    }

    QImage image;
    QSGTexture *texture;
};

ImageItem::ImageItem(QQuickItem *parent)
    : QQuickItem(parent),
    d(new ImageItemData)
{
}

ImageItem::~ImageItem()
{
    delete d;
}

void ImageItem::setImage(const QImage &image)
{
    qDebug() << "setting image " << image.width() << image.height();

    d->image = image;
    setFlag(ItemHasContents, true);
}

QSGNode *ImageItem::updatePaintNode(QSGNode *node, UpdatePaintNodeData *)
{
    QSGSimpleTextureNode *n = static_cast<QSGSimpleTextureNode *>(node);

    qDebug() << "update paint node";
    if (!node && !d->image.isNull()) {
        qDebug() << "Creating texture node";
        n = new QSGSimpleTextureNode;

        d->texture = canvas()->createTextureFromImage(d->image);
        qDebug() << "texture is" << d->texture;
        n->setTexture(d->texture);
        n->setRect(0, 0, d->image.width(), d->image.height());
    }

    return n;
}


